Prior_prob_alphaD <-
function(aD){
		stats::dexp(aD,log=TRUE)
	}
